@@ -184,12 +184,12 @@ def get_stage(lookupValue: "Value to look up (must be unique in the DB!)",
 
 
 def set_stage(lookupValue: "Value to look up (must be unique in the DB!)",
-          stage: "Production stage to set",
-          project: "ATLAS Project" = 'S',
-          subProject: "ATLAS Subproject" = "SE",
-          lookupKey: "Key that corresponds to VALUE" = 'serialNumber',
-          componentType: "Type of component" = 'BT',
-          comment: "Reason for production stage change" = ""):
+              stage: "Production stage to set",
+              project: "ATLAS Project" = 'S',
+              subProject: "ATLAS Subproject" = "SE",
+              lookupKey: "Key that corresponds to VALUE" = 'serialNumber',
+              componentType: "Type of component" = 'BT',
+              comment: "Reason for production stage change" = ""):
     'Set production stage for a component. Ex: didis stage "20USECP9000050" "" componentType="COOLING_PIPE"????'
     logger.info(f"Getting component from the DB")
     component = lookup(project=project, subProject=subProject, lookupKey=lookupKey, value=[
@@ -225,9 +225,11 @@ def set_stage(lookupValue: "Value to look up (must be unique in the DB!)",
         logger.error(
             f"DB error, is {stage} a valid stage for {componentType}?")
 
+
 def stage(*args, **kwargs):
     return set_stage(*args, **kwargs)
 
+
 def skeleton(test: "Type of test",
              componentType: "Type of component" = "BT",
              project: "ATLAS Project" = 'S',
@@ -347,6 +349,7 @@ def assemble(parent:     "Parent component identifier (ATLAS SN or alternative I
              child:      "Child component identifier (ATLAS SN or alternative ID)",
              parentAID:  "Parent identifier is an alternative ID" = False,
              childAID:   "Child identifier is an alternative ID" = False,
+             slot:       "Target component slot id" = None,
              properties: "Properties collection (dict or .json file)" = None):
     "Assemble a component"
     if isinstance(properties, str) and os.path.isfile(properties):
@@ -369,6 +372,8 @@ def assemble(parent:     "Parent component identifier (ATLAS SN or alternative I
             "alternativeIdentifierChild": childAID,
             "properties": properties
         }
+        if slot is not None:
+            data["slot"] = slot
         client = itkdb.Client()
         client.post('assembleComponent', json=data)
         logger.info(f"Assembled components {parent} and {child}")
@@ -496,13 +501,35 @@ def testresult(tid: "Test ID",
             "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
 
 
+def get_slots(componentID: "Component identifier or ATLAS serial number",
+              returnResults: "Return lookup results (useful if not used from CLI)" = False):
+    """Get child component slots."""
+    try:
+        logger.info(f"Getting slots for component {componentID}")
+        client = itkdb.Client()
+        result = client.get('getComponent', json={'component': componentID})
+        children = result["children"]
+        logger.info(f"Found {len(children)} child component slots")
+        for i, c in enumerate(children):
+            type = c["type"]["code"]
+            id = c["id"]
+            logger.info(f"Slot {i}: {type} in {id}")
+        if returnResults or __name__ != '__main__':
+            return children
+    except Exception as e:
+        logger.error(e)
+        logger.error("Error while trying to get connection to DB")
+        logger.info(
+            "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
+
+
 def main():
     parser = argh.ArghParser()
     parser.add_commands([authenticate, register, lookup,
                         attach, tests, get_stage, set_stage,
                         skeleton, upload, testruns,
                         testfile, assemble, property,
-                        comment, ship, testresult])
+                        comment, ship, testresult, get_slots])
     parser.dispatch()
 
 
